/***********************************/
/*** Fig4_PanelC.do				 ***/
/*** Effect on non-state firm TFP***/
/*** Hetero graph by initial conditions ***/
/*** TFP from individual firm data '04 ***/
/***********************************/
version 12.0
clear all
set more off
set matsize 5000

use "Data/_Sample_FirmTFP.dta", replace

/*********************************************/
/*** Heterogeneous graph: Fig 4 Panel C	 ***/
/*********************************************/
/*** Residual ***/
# delimit ;
ds 	ln_dist2rail80
	ln_dist2provcap ln_meanelev meanslope 	
	urbanrt64 ln_popden64 emp36_pop64_rt
	LMSEmp_mining_emp82_rt
;
# delimit cr
local cvlist `r(varlist)'

qui {
xi: reg TFP `cvlist' i.reg2d82 i.ind2 [aw = wgt], cluster(pref82_code)
predict Y_res, res
xi: reg LMSEmp_nm_emp82_rt `cvlist' i.reg2d82 i.ind2 [aw = wgt], cluster(pref82_code)
predict X_res, res
}

/*** Collapse to prefecture level ***/
collapse (mean) Y_res X_res urbanrt64 [aw = wgt], by(pref82_code)

summ urbanrt64, de
local medurbanrt64 = `r(p50)'


# delimit ;
twoway 	(scatter Y_res X_res if urbanrt64 >= `medurbanrt64', msize(small) mcolor(dknavy) msymbol(dot))
		(scatter Y_res X_res if urbanrt64 < `medurbanrt64', msize(medium) mcolor(maroon) msymbol(x))
		(lfit Y_res X_res if urbanrt64 >= `medurbanrt64', lpattern(solid) lcolor(dknavy) lwidth(medium))
		(lfit Y_res X_res if urbanrt64 < `medurbanrt64', lpattern(solid) lcolor(maroon) lwidth(medium))
		(lowess Y_res X_res if urbanrt64 >= `medurbanrt64', lpattern(dash) lcolor(dknavy) lwidth(med))		
		(lowess Y_res X_res if urbanrt64 < `medurbanrt64', lpattern(dash) lcolor(maroon) lwidth(med))		
	, title("")
	 xtitle("TF-built manufacturing capacity, residual") ytitle("average TFP, residual")
	 legend(off)
	graphregion(color(white))
	legend(on order(1 "64 urban rate above median" 2 "64 urban rate below median" 3 "linear fit" 
					4 "linear fit" 5 "local weighted smoothing" 6 "local weighted smoothing") col(2))	

;
# delimit cr
graph export "Output/Fig4_PanelC.pdf", replace
* end


