/***********************************/
/*** Tab10.do					 ***/
/*** Migration and Structural Transformation***/
/***********************************/
version 12.0
clear all
set more off
use "Data/_PrefSample.dta", clear

/***********************************/
/*** Regressions				 ***/
/***********************************/
/*** Var list ***/
# delimit ;
ds 		ln_dist2rail80
		ln_dist2provcap ln_meanelev meanslope 	
		urbanrt64 
		ln_popden64 emp36_pop64_rt
	 	LMSEmp_mining_emp82_rt
;
# delimit cr
local cvlist `r(varlist)'

qui ds InMigRt05 ruralempshare_manu00_mi
local depvlist `r(varlist)'

/*** Regs ***/
local n = 1
qui foreach depvar of local depvlist {
	xi: ivreg2 `depvar' (LMSEmp_nm_emp82_rt = ln_dist2rail62) `cvlist' i.reg2d82 if sample1 == 1, robust
	eststo Mig_Col`n'
	estadd scalar FSF = `e(rkf)'
	summ `depvar' if e(sample) == 1
	estadd scalar depvarmean = `r(mean)'
	
	local n = `n' + 1
}

/***********************************/
/*** Display and save 			 ***/
/***********************************/
# delimit ;
esttab Mig_Col*, 
	title("Mig and Local Structural Transformation")
	se(3) b(3)
	keep(LMSEmp_nm_emp82_rt)
	mtitle(InMig rrl00)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N depvarmean FSF, fmt(%6.0f %6.3f %6.3f))
	modelwidth(7)
;
# delimit cr


# delimit ;
esttab Mig_Col* using "Output/Tab10.tex"
	, replace 
	title("Mig and Local Structural Transformation")
	se(3) b(3)
	keep(LMSEmp_nm_emp82_rt)
	mtitle(InMig rrl00)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N depvarmean FSF, fmt(%6.0f %6.3f %6.3f))
	modelwidth(7)
;
# delimit cr

* end
