/***********************************/
/*** Tab4.do					 ***/
/*** Determinants of TF-built manu capacity***/
/***********************************/
version 12.0
clear all
set more off
use "Data/_PrefSample.dta", clear

/***********************************/
/*** Regression 				 ***/
/***********************************/
set more off
local vlist1 "ln_dist2rail80 i.reg2d82"
local vlist2 "ln_dist2rail62 ln_dist2rail80 i.reg2d82"
local vlist3 "ln_dist2rail62 ln_dist2rail80 meanslope meanelev ln_dist2provcap i.reg2d82"
local vlist4 "urbanrt64 i.reg2d82"
local vlist5 "urbanrt64 ln_popden64 emp36_pop64_rt i.reg2d82"
local vlist6 "ln_dist2rail62 ln_dist2rail80 meanslope meanelev ln_dist2provcap urbanrt64 i.reg2d82"
local vlist7 "ln_dist2rail62 ln_dist2rail80 meanslope meanelev ln_dist2provcap urbanrt64 ln_popden64 emp36_pop64_rt i.reg2d82"

/*** Joint tests ***/
reg LMSEmp_nm_emp82_rt `vlist2' if sample3 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0

reg LMSEmp_nm_emp82_rt `vlist2' if sample1 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0
		
reg LMSEmp_nm_emp82_rt `vlist3' if sample3 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0
	
reg LMSEmp_nm_emp82_rt `vlist3' if sample1 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0


reg LMSEmp_nm_emp82_rt `vlist6' if sample3 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0

reg LMSEmp_nm_emp82_rt `vlist7' if sample3 == 1, robust
test ln_dist2rail62 = ln_dist2rail80 = 0
	
/*** Regressions 	***/
eststo clear
qui forvalues i = 1/7 {
	/* In TF */
	reg LMSEmp_nm_emp82_rt `vlist`i'' if sample1 == 1, robust
	eststo TF_Col`i'
	summ LMSEmp_nm_emp82_rt if e(sample) == 1
	estadd scalar MeanDepVar = `r(mean)' 
	if `i' == 5 | `i' == 7  {
		test urbanrt64 ln_popden64  emp36_pop64_rt
		estadd scalar joint_p = `r(p)'
	}

	/* Outside of TF */	
	reg LMSEmp_nm_emp82_rt `vlist`i'' if sample3 == 1, robust
	eststo NTF_Col`i'
	summ LMSEmp_nm_emp82_rt if e(sample) == 1
	estadd scalar MeanDepVar = `r(mean)'
	if `i' == 5 | `i' == 7 {
		test urbanrt64 ln_popden64  emp36_pop64_rt
		estadd scalar joint_p = `r(p)'
	}	
}

/***********************************/
/*** Display and save 			 ***/
/***********************************/
local title1 = "TF, urbanrt64<=15 "
local title3 = "non-TF"
	/* Display */
# delimit ;
esttab TF_Col*
	, drop(*reg2d82*)
	se(3) b(3) 
	title("TF Region")
	star(* 0.1 ** 0.05 *** 0.01)
	stat(N r2 MeanDepVar joint_p, fmt(%6.0f %6.3f %6.3f %6.3f))
	modelwidth(8)
;
# delimit cr

# delimit ;
esttab NTF_Col*
	, drop(*reg2d82*)
	se(3) b(3) 
	title("Non-TF Region")
	star(* 0.1 ** 0.05 *** 0.01)
	stat(N r2 MeanDepVar joint_p, fmt(%6.0f %6.3f %6.3f %6.3f))
	modelwidth(8)
;
# delimit cr

	/* Save */
# delimit ;
esttab TF_Col* using "Output/Tab4A.tex"
	, replace
	drop(*reg2d82*)
	se(3) b(3) 
	title("TF Region")
	star(* 0.1 ** 0.05 *** 0.01)
	stat(N r2 MeanDepVar joint_p, fmt(%6.0f %6.3f %6.3f %6.3f))
	modelwidth(8)
;
# delimit cr

# delimit ;
esttab NTF_Col* using "Output/Tab4B.tex"
	, replace
	drop(*reg2d82*)
	se(3) b(3) 
	title("Non-TF Region")
	star(* 0.1 ** 0.05 *** 0.01)
	stat(N r2 MeanDepVar joint_p, fmt(%6.0f %6.3f %6.3f %6.3f))
	modelwidth(8)
;
# delimit cr



* end
