/***********************************/
/*** Tab7.do					 ***/
/*** Robustness in measurement	 ***/
/***********************************/
version 12.0
clear all
set more off
use "Data/_PrefSample.dta", clear

/***********************************/
/*** Regressions				 ***/
/***********************************/
# delimit ;
ds ln_dist2rail80 
	meanslope ln_meanelev ln_dist2provcap 
	urbanrt64 ln_popden64 emp36_pop64_rt 
	LMSEmp_mining_emp82_rt
;
# delimit cr
local covlist `r(varlist)'

qui {
/* Col 1: Emp share from smaller plants (1982 Population Census) */
xi: reg LMSEmp_nm_emp82_rt ln_dist2rail62 `covlist' Small_IndEmp_emp82_rt  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (LMSEmp_nm_emp82_rt = ln_dist2rail62) 
	Small_IndEmp_emp82_rt
	`covlist' i.reg2d82 if sample1 == 1
	, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM1

/* Col 2: Emp share from firms built during the TF */
xi: reg InvRt_TF ln_dist2rail62 InvRt_PreTF `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (InvRt_TF = ln_dist2rail62) 
	InvRt_PreTF
	`covlist' i.reg2d82 if sample1 == 1
	, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM2

/*** Col 3: Ind output in 78 ***/
xi: reg prefindop78_pc ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (prefindop78_pc = ln_dist2rail62) 
		`covlist' i.reg2d82 
		if sample1 == 1
		, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM3

/*** Col 4: log ind output in 78 ***/
gen ln_prefindop78_pc = ln(prefindop78_pc + 1)

xi: reg ln_prefindop78_pc ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (ln_prefindop78_pc = ln_dist2rail62) 
		`covlist' i.reg2d82 
		if sample1 == 1
		, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM4

/*** Col 5: Growth in ind output 64-78 ***/
xi: reg prefindop6478_pc64 ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (prefindop6478_pc64 = ln_dist2rail62) 
		`covlist' i.reg2d82 
		if sample1 == 1
		, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM5

/*** Col 6: Growth in log ind output 64-78 ***/
gen ln_indprod_pc_6478 = ln(indprod78/pop64 + 0.01) - ln(indprod64/pop64 + 0.01)

xi: reg ln_indprod_pc_6478 ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]

# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (ln_indprod_pc_6478 = ln_dist2rail62) 
		`covlist' i.reg2d82 
		if sample1 == 1
		, robust
;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM6

/*** Col 7: # of firms ***/
xi: reg NFirm85_emp82_rt ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (NFirm85_emp82_rt = ln_dist2rail62) `covlist' i.reg2d82 if sample1 == 1, robust;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM7

/*** Col 8: Designated industrial center ***/
xi: reg TFCenter ln_dist2rail62 `covlist'  i.reg2d82 if sample1 == 1, robust
local b1 = _b[ln_dist2rail62]
local se1 = _se[ln_dist2rail62]
local b2 = _b[ln_dist2rail80]
local se2 = _se[ln_dist2rail80]
# delimit ;
xi: ivreg2 Emp04_nm_emp00_rt (TFCenter = ln_dist2rail62) `covlist' i.reg2d82 if sample1 == 1, robust;
# delimit cr
estadd scalar FSF = `e(rkf)'
estadd scalar b1 = round(`b1',0.001)
estadd scalar se1 = round(`se1',0.001)
estadd scalar b2 = round(`b2',0.001)
estadd scalar se2 = round(`se2',0.001)
eststo RobM8

}

/*** Display and save ***/
# delimit ;  
esttab RobM*, 
	title("Robustness in Measurement")
	mtitle(Small TFM Ind78 lnInd78 Ind6478 lnInd6478 NFirm TFCenter)
	se(3) b(3)
	keep(LMSEmp_nm_emp82_rt Small_IndEmp_emp82_rt 
			InvRt_PreTF InvRt_TF
			prefindop78_pc  ln_prefindop78_pc prefindop6478_pc64 ln_indprod_pc_6478
			NFirm85_emp82_rt
			TFCenter)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N FSF b1 se1 b2 se2, fmt(%6.0f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f ))
	modelwidth(7)
;
# delimit cr

# delimit ;  
esttab RobM* using "Output/Tab7.tex"
	, replace 
	title("Robustness in Measurement")
	mtitle(Small TFM Ind78 lnInd78 Ind6478 lnInd6478 NFirm TFCenter)
	se(3) b(3)
	keep(LMSEmp_nm_emp82_rt Small_IndEmp_emp82_rt 
			InvRt_PreTF InvRt_TF
			prefindop78_pc  ln_prefindop78_pc prefindop6478_pc64 ln_indprod_pc_6478
			NFirm85_emp82_rt
			TFCenter)
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N FSF b1 se1 b2 se2, fmt(%6.0f %6.3f %6.3f %6.3f %6.3f %6.3f %6.3f ))
	modelwidth(7)
;
# delimit cr


* end
