/***********************************/
/*** Linkage, Pref-Ind, TFP		 ***/
/*** Tabl9PanelB_PrefInd_TFP	 ***/
/***********************************/
version 12.0
clear all
set more off
use "Data/_Sample_FirmTFP.dta", clear

/***********************************/
/*** II. Regressions			 ***/
/***********************************/
set more off
eststo clear

ds Emp85_emp82_rt cps_leave uctp techin_pr techout_or use_man out_man
local linkvarlist `r(varlist)'

/*** Controls ***/
# delimit ;
ds 		ln_dist2rail80
		ln_dist2provcap ln_meanelev meanslope 	
		urbanrt64 ln_popden64 
	 	emp36_pop64_rt
	 	LMSEmp_mining_emp82_rt
;
# delimit cr
local covlist `r(varlist)'

/*** All control for pref FE ***/
local n = 1	
qui foreach cvar of local linkvarlist {
	/*** Control for prefecture FE ***/
	/*** TFP ***/			
	xi: areg TFP `cvar' i.ind2 [aw = wgt], a(pref82_code) cluster(pref82_code)
	eststo TFP_Link_Col`n'
	
	local n = `n' + 1
}


/***********************************/
/*** III. Display				 ***/
/***********************************/
# delimit ;
esttab TFP_Link_Col*,
	title("Industrial Linkage and TFP, private firms, pref FE")
	mtitle(Own2d WorkerTrans Cite TechIn TechOut ManuIn ManuOut)
	se(3) b(3)
	keep(Emp85_emp82_rt cps_leave uctp techin_pr techout_or use_man out_man) 
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N r2, fmt(%6.0f %6.3f))
	modelwidth(8)
;
# delimit cr

# delimit ;
esttab TFP_Link_Col* using "Output/Tab9_PanelB.tex"
	, replace 
	title("Industrial Linkage and TFP, private firms, pref FE")
	mtitle(Own2d WorkerTrans Cite TechIn TechOut ManuIn ManuOut)
	se(3) b(3)
	keep(Emp85_emp82_rt cps_leave uctp techin_pr techout_or use_man out_man) 
	star(* 0.1 ** 0.05 *** 0.01)
	stats(N r2, fmt(%6.0f %6.3f))
	modelwidth(8)
;
# delimit cr

* end




